@@ -1,5 +1,5 @@
 /*
-    suPHP - (c)2002-2005 Sebastian Marsching <sebastian@marsching.com>
+    suPHP - (c)2002-2008 Sebastian Marsching <sebastian@marsching.com>
 
     This file is part of suPHP.
 
@@ -36,12 +36,12 @@ std::string suPHP::File::getPath() const{
     return this->path;
 }
 
-SmartPtr<std::ifstream> suPHP::File::getInputStream() throw (IOException) {
+SmartPtr<std::ifstream> suPHP::File::getInputStream() const throw (IOException) {
     std::ifstream* infile = new std::ifstream();
     infile->open(this->path.c_str());
     if (infile->bad() || infile->fail()) {
-	throw IOException("Could not open file " + 
-			  this->path + " for reading", __FILE__, __LINE__);
+        throw IOException("Could not open file " + 
+                          this->path + " for reading", __FILE__, __LINE__);
     }
     return SmartPtr<std::ifstream>(infile);
 }
@@ -108,6 +108,7 @@ GroupInfo suPHP::File::getGroup() const throw (SystemException) {
     return API_Helper::getSystemAPI().File_getGroup(*this);
 }
 
+
 bool suPHP::File::isSymlink() const throw (SystemException) {
     return API_Helper::getSystemAPI().File_isSymlink(*this);
 }
